/* No Interrupt Version by group 12*/

#ifndef F_CPU
#define F_CPU 16000000UL 	/* MCU work at clock 16MHz */
#endif

#include <avr/io.h>
#include <avr/interrupt.h>  /* for sei() */
#include <util/delay.h>     /* for _delay_ms() */
#include <avr/pgmspace.h>   /* required by usbdrv.h */
#include "usbdrv.h" 

#define READ_CHECK 0
#define READ_PULSE 1

uchar zero = 0;

/* ------------------------------------------------------------------------- */
/* ----------------- Description : pins of Microcontroller ----------------- */
/* ------------------------------------------------------------------------- */
 
/*	PB3 is a double check
	PB2 is a sensor output */

/* ------------------------------------------------------------------------- */
/* --------------------- Description : Pin of Jumpers ---------------------- */
/* ------------------------------------------------------------------------- */

/*  PN0,PN1 is a Vcc
	PN6 is a double check 
   	PD7 is a sensor output */
/* ------------------------------------------------------------------------- */
/* ---------------------------- Utility Functions -------------------------- */
/* ------------------------------------------------------------------------- */

uint8_t in_b(uint8_t pin)
{
    // read logic level of port-B's pin
    DDRB &= ~(1<<pin);
	PORTB |= (1<<pin);
    return ((PINB & (1<<pin))>>pin);    
} 

/* ------------------------------------------------------------------------- */
/* ----------------------------- USB interface ----------------------------- */
/* ------------------------------------------------------------------------- */

usbMsgLen_t usbFunctionSetup(uchar data[8])
{
    usbRequest_t *rq = (void *)data;
	static uchar dataBuffer[8];  /* must stay valid when usbFunctionSetup returns */
    if (rq->bRequest == READ_CHECK)
    {
		usbMsgPtr = (uchar) !in_b(3);
        return 1;
    }
    else if (rq->bRequest == READ_PULSE)
    {
		int i;
		for (i = 0 ; i < 8 ; i++) {
			dataBuffer[i] = !in_b(2);
			_delay_ms(0.56);
		}
			usbMsgPtr = dataBuffer;
        return 8;
    }
    return 0;   /* default for not implemented requests: return no data back to host */
}

int main(void)
{
	// Initialize Section
	DDRB    = 0b11110011; 	// PB2, PB3 = Input

	// Usb Connection Section
    usbInit();
    usbDeviceDisconnect();  /* enforce re-enumeration, do this while interrupts are disabled! */
    _delay_ms(300);
    usbDeviceConnect();
    sei();
    for(;;){                /* main event loop */
        usbPoll();
    }
    return 0;
}
